#' rhandsontable
#'
#' R interface for creating tables using Handsontable, url{http://http://handsontable.com/}
#'
#' For full documentation on the package, visit \url{http://jrowen.github.io/rhandsontable/}
#' @name rhandsontable-package
#' @docType package
#' @import htmlwidgets jsonlite
#' @importFrom utils modifyList capture.output head tail
#' @importFrom methods as
NULL

#' rhandsontable exported operators
#'
#' The following functions are imported and then re-exported
#' from the rhandsontable package to enable use of the magrittr
#' pipe operator with no additional library calls
#'
#' @name rhandsontable-exports
NULL

#' @importFrom magrittr %>%
#' @name %>%
#' @export
#' @rdname rhandsontable-exports
NULL
